@@ -28,8 +28,6 @@ class ConfiguredFormAdmin(ContentEditor):
 
         if type := obj.type:
             if msgs := list(type.validate(obj)):
-                for msg in msgs:
-                    msg.add_to(request)
                 messages.warning(
                     request,
                     format_html(
@@ -37,6 +35,8 @@ class ConfiguredFormAdmin(ContentEditor):
                         obj=obj_repr,
                     ),
                 )
+                for msg in msgs:
+                    messages.add_message(request, msg.level, msg.message)
             else:
                 messages.success(
                     request, format_html(_('"{obj}" has been validated.'), obj=obj_repr)
@@ -55,6 +55,8 @@ class ConfiguredFormAdmin(ContentEditor):
 
     def save_related(self, request, form, formsets, change):
         super().save_related(request, form, formsets, change=change)
+        # Only validate if navigating away from this page. Otherwise validation
+        # will happen in render_change_form anyway.
         if request.method == "POST" and any(
             key in request.POST for key in NO_CONTINUE_PARAMETERS
         ):
@@ -67,7 +69,7 @@ class ConfiguredFormAdmin(ContentEditor):
 
 
 class FormFieldInline(ContentEditorInline):
-    core_fields = ["label", "name", "is_required"]
+    core_fields = ["name", "label", "is_required"]
     advanced_fields = ["help_text"]
 
     def get_fieldsets(self, request, obj=None):
@@ -100,7 +102,7 @@ class SimpleFieldInline(FormFieldInline):
 
         elif model.TYPE in {T.SELECT, T.RADIO}:
             kwargs.setdefault(
-                "core_fields", ["label", "name", "is_required", "choices"]
+                "core_fields", ["name", "label", "is_required", "choices"]
             )
             kwargs.setdefault("advanced_fields", ["help_text", "default_value"])
 
